<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'activer_plugin' => 'Activate plugin',
'affichage' => 'Display',
'aide_non_disponible' => 'This part of the online help is not yet available in the present language.',
'auteur' => 'Author:',
'avis_acces_interdit' => 'Access forbidden.',
'avis_article_modifie' => 'Warning, @nom_auteur_modif@ has worked on this article @date_diff@ minutes ago',
'avis_aucun_resultat' => 'No results found.',
'avis_chemin_invalide_1' => 'The path you have selected',
'avis_chemin_invalide_2' => 'does not seem valid. Please return to the previous page and verify the information provided.',
'avis_connexion_echec_1' => 'The connection to the SQL server failed.',
'avis_connexion_echec_2' => 'Go back to the previous page, and verify the information you have provided.',
'avis_connexion_echec_3' => '<b>N.B.</b> On many servers, you must <b>request</b> the activation of your access to the SQL database before you can use it. If you are unable to connect, check that this activation has taken place.',
'avis_connexion_ldap_echec_1' => 'Connection to the LDAP server failed.',
'avis_connexion_ldap_echec_2' => 'Go back to the previous page, and verify the information you have provided.',
'avis_connexion_ldap_echec_3' => 'Alternatively, do not use LDAP support to import users.',
'avis_conseil_selection_mot_cle' => '<b>Important group:</b> It is very strongly advised to select a keyword in this group.',
'avis_deplacement_rubrique' => 'Warning! This section contains @contient_breves@ news item@scb@: if you move it , please check this box to confirm.',
'avis_destinataire_obligatoire' => 'You must select a recipient before sending this message.',
'avis_doublon_mot_cle' => 'A word with this title already exists. Are you sure you want to create another?', # MODIF
'avis_erreur_connexion_mysql' => 'SQL connection error',
'avis_erreur_version_archive' => '<b>Warning! The file @archive@ was created by
    a version of SPIP other than the one you have
    installed.</b> You are facing great
    difficulties: the risk of destroying your database,
    various malfunctions of your site, etc. Do not
    submit this import request.<p>For more
    information, please see <a href="@spipnet@">
                                the SPIP documentation</a>.</p>',
'avis_espace_interdit' => '<b>Forbidden area</b><div>SPIP is already installed.</div>',
'avis_lecture_noms_bases_1' => 'The installer could not read the names of the installed databases.',
'avis_lecture_noms_bases_2' => 'Either no database is available, or the feature allowing the listing of the databases was disabled
		for security reasons (which is the case with a lot of hosts).',
'avis_lecture_noms_bases_3' => 'In case the second alternative was true, it is possible that a database named after your login could be usable:',
'avis_non_acces_message' => 'You do not have access to this message.',
'avis_non_acces_page' => 'You do not have access to this page.',
'avis_operation_echec' => 'The operation failed.',
'avis_operation_impossible' => 'Operation impossible',
'avis_probleme_archive' => 'Reading error in file @archive@',
'avis_site_introuvable' => 'Site not found',
'avis_site_syndique_probleme' => 'Warning: the syndication of this site has encountered a problem; consequently the system has been temporarily interrupted. Please check the address of this site\'s syndication file (<b>@url_syndic@</b>), and try once again to retrieve the information it provides.',
'avis_sites_probleme_syndication' => 'These sites encountered a syndication problem',
'avis_sites_syndiques_probleme' => 'These syndicated sites generated a problem',
'avis_suppression_base' => 'WARNING, data deletion is irreversible',
'avis_version_mysql' => 'Your version of SQL (@version_mysql@) does not allow auto repair of the database tables.',

// B
'bouton_acces_ldap' => 'Add an access to LDAP >>',
'bouton_ajouter' => 'Add',
'bouton_ajouter_participant' => 'ADD A PARTICIPANT:',
'bouton_annonce' => 'ANNOUNCEMENT',
'bouton_annuler' => 'Cancel',
'bouton_checkbox_envoi_message' => 'possibility to send a message',
'bouton_checkbox_indiquer_site' => 'You must enter the name of a Web site',
'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'site administrators',
'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'editors',
'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'visitors of the public site when they post a message on a forum.',
'bouton_checkbox_signature_unique_email' => 'only one signature per e-mail address',
'bouton_checkbox_signature_unique_site' => 'only one signature per Web site',
'bouton_demande_publication' => 'Request the publication of this article',
'bouton_desactive_tout' => 'Disable all',
'bouton_desinstaller' => 'Uninstall',
'bouton_effacer_index' => 'Delete indexing',
'bouton_effacer_statistiques' => 'Delete the statistics',
'bouton_effacer_tout' => 'Delete ALL',
'bouton_envoi_message_02' => 'SEND A MESSAGE',
'bouton_envoyer_message' => 'Final message: send',
'bouton_forum_petition' => 'FORUM &amp; PETITION',
'bouton_modifier' => 'Modify',
'bouton_pense_bete' => 'PERSONAL MEMO',
'bouton_radio_activer_messagerie' => 'Enable internal messaging',
'bouton_radio_activer_messagerie_interne' => 'Enable internal messaging',
'bouton_radio_activer_petition' => 'Activating the petition',
'bouton_radio_afficher' => 'Show',
'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Appear in the list of connected editors',
'bouton_radio_articles_futurs' => 'to future articles only (no action on the database).',
'bouton_radio_articles_tous' => 'to all articles without any exception.',
'bouton_radio_articles_tous_sauf_forum_desactive' => 'to all articles, except those with disabled forums.',
'bouton_radio_desactiver_messagerie' => 'Disable messaging',
'bouton_radio_enregistrement_obligatoire' => 'Required registration (
  users must subscribe by providing their e-mail address before
  being able to post contributions).',
'bouton_radio_envoi_annonces_adresse' => 'Send announcements to the address:',
'bouton_radio_envoi_liste_nouveautes' => 'Send latest news list',
'bouton_radio_moderation_priori' => 'Pre-moderation (
 contributions will be shown only after validation by
 administrators).',
'bouton_radio_modere_abonnement' => 'registration required',
'bouton_radio_modere_posteriori' => 'post-moderation',
'bouton_radio_modere_priori' => 'pre-moderation',
'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'Do not appear in the list of connected editors',
'bouton_radio_non_envoi_annonces_editoriales' => 'Do not send any editorial announcements',
'bouton_radio_non_syndication' => 'No syndication',
'bouton_radio_pas_petition' => 'No petition',
'bouton_radio_petition_activee' => 'Petition activated',
'bouton_radio_publication_immediate' => 'Immediate publication of messages
 (contributions will be shown as soon as they are sent, administrators can
 then delete them).',
'bouton_radio_sauvegarde_compressee' => 'save as compressed in @fichier@',
'bouton_radio_sauvegarde_non_compressee' => 'save as uncompressed in @fichier@',
'bouton_radio_supprimer_petition' => 'Delete the petition',
'bouton_radio_syndication' => 'Syndication:',
'bouton_redirection' => 'REDIRECT',
'bouton_relancer_installation' => 'Re-launch installation',
'bouton_restaurer_base' => 'Restore the database',
'bouton_suivant' => 'Next',
'bouton_tenter_recuperation' => 'Repairing attempt',
'bouton_test_proxy' => 'Test the proxy',
'bouton_vider_cache' => 'Empty the cache',
'bouton_voir_message' => 'Preview message before validating',

// C
'cache_mode_compresse' => 'The cache files are saved in compressed mode.',
'cache_mode_non_compresse' => 'The cache files are written in uncompressed mode.',
'cache_modifiable_webmestre' => 'This parameter can be modified by the webmaster.',
'calendrier_synchro' => 'If you use a calendar application compatible with <b>iCal</b>, you can synchronize it with this site\'s information.',
'config_activer_champs' => 'Activate the following fields',
'config_choix_base_sup' => 'Name a database on this server',
'config_erreur_base_sup' => 'SPIP does not have access to the available databases',
'config_info_base_sup' => 'If you need to query other databases using SPIP, whether on the same SQL server or elsewhere, use the form below to declare them. If you leave some fields empty, then the connection details to the main database will be used.',
'config_info_base_sup_disponibles' => 'Additional databases to which queries may be sent:',
'config_info_enregistree' => 'The new configuration has been saved',
'config_info_logos' => 'Each element of the site can have its logo and also a "mouseover" logo',
'config_info_logos_utiliser' => 'Use logos',
'config_info_logos_utiliser_non' => 'Do not use logos',
'config_info_logos_utiliser_survol' => 'Use "mouseover" logos',
'config_info_logos_utiliser_survol_non' => 'Do not use "mouseover" logos',
'config_info_redirection' => 'By activating this option you can create virtual articles, which are simply references to articles published on other sites whether SPIP sites or not.',
'config_redirection' => 'Virtual articles',
'config_titre_base_sup' => 'Declaration of an additional database',
'config_titre_base_sup_choix' => 'Choose an additional database',
'connexion_ldap' => 'Connection:',
'copier_en_local' => 'Copy to local site',

// D
'date_mot_heures' => 'H',
'diff_para_ajoute' => 'Added paragraph',
'diff_para_deplace' => 'Moved paragraph',
'diff_para_supprime' => 'Deleted paragraph',
'diff_texte_ajoute' => 'Added text',
'diff_texte_deplace' => 'Moved text',
'diff_texte_supprime' => 'Deleted text',
'double_clic_inserer_doc' => 'Double-click to insert this shortcut in the text',

// E
'email' => 'e-mail',
'email_2' => 'e-mail:',
'en_savoir_plus' => 'To know more',
'entree_adresse_annuaire' => 'Directory\'s address',
'entree_adresse_email' => 'Your e-mail address',
'entree_adresse_fichier_syndication' => 'Address of file for syndication:',
'entree_adresse_site' => '<b>Site URL</b> [Required]',
'entree_base_donnee_1' => 'Database address',
'entree_base_donnee_2' => '(Often, this address matches the address of your site, sometimes it corresponds to the name &laquo;localhost&raquo;, and sometimes it is left completely empty.)',
'entree_biographie' => 'Short biography in a few words.',
'entree_breve_publiee' => 'Is this news item to be published?',
'entree_chemin_acces' => '<b>Enter</b> the path:',
'entree_cle_pgp' => 'Your PGP key',
'entree_contenu_rubrique' => '(Content of the section in a few words.)',
'entree_description_site' => 'Site description',
'entree_identifiants_connexion' => 'Your connection identifiers...',
'entree_informations_connexion_ldap' => 'Please fill this form with the LDAP connection information. You will be provided with this information by your system or network administrator.',
'entree_infos_perso' => 'Who are you?',
'entree_interieur_rubrique' => 'In section:',
'entree_liens_sites' => '<b>Hyperlink</b> (reference, site to visit...)',
'entree_login' => 'Your login',
'entree_login_connexion_1' => 'Connection login',
'entree_login_connexion_2' => '(Sometimes matches your FTP access login and sometimes left empty)',
'entree_login_ldap' => 'Initial LDAP login',
'entree_mot_passe' => 'Your password',
'entree_mot_passe_1' => 'Connection password',
'entree_mot_passe_2' => '(Sometimes matches your FTP access password and sometimes left empty)',
'entree_nom_fichier' => 'Please enter the filename @texte_compresse@:',
'entree_nom_pseudo' => 'Your name or alias',
'entree_nom_pseudo_1' => '(Your name or alias)',
'entree_nom_site' => 'Your site\'s name',
'entree_nouveau_passe' => 'New password',
'entree_passe_ldap' => 'Password',
'entree_port_annuaire' => 'Port number of the directory',
'entree_signature' => 'Signature',
'entree_texte_breve' => 'Text of news item',
'entree_titre_obligatoire' => '<b>Title</b> [Required]<br />',
'entree_url' => 'Your site\'s URL',
'erreur_plugin_desinstalation_echouee' => 'The uninstallation of the plugin failed. You may, however, deactivate it.',
'erreur_plugin_fichier_absent' => 'File missing',
'erreur_plugin_fichier_def_absent' => 'Definition file missing',
'erreur_plugin_nom_fonction_interdit' => 'Prohibited function name',
'erreur_plugin_nom_manquant' => 'Missing plugin name',
'erreur_plugin_prefix_manquant' => 'Plugin\'s namespace undefined',
'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt; missing in the definition file',
'erreur_plugin_version_manquant' => 'Missing version of the plugin',

// F
'forum_info_original' => 'original',

// H
'htaccess_a_simuler' => 'Warning: your HTTP server\'s configuration ignores the @htaccess@ files. In order to guarantee a good security, you must modify the server\'s configuration concerning this matter, or you have to make sure that the constants @constantes@ (which could be defined in the file mes_options.php) have as their values directories outside @document_root@.',
'htaccess_inoperant' => 'inoperative htaccess',

// I
'ical_info1' => 'This page presents you with several methods to keep in contact with this site\'s activity.',
'ical_info2' => 'For more information, do not hesitate to visit <a href="@spipnet@">SPIP\'s documentation</a>.',
'ical_info_calendrier' => 'Two calendars are at your disposal. The first is a site map showing all the published articles. The second contains editorial annoucements as well as your latest private messages: it is reserved for you thanks to a personal key that you can modify at any time by renewing your password.',
'ical_lien_rss_breves' => 'Syndication of the site\'s news items',
'ical_methode_http' => 'Downloading',
'ical_methode_webcal' => 'Synchronization (webcal://)',
'ical_texte_js' => 'A line of javascript allows to display,  very easily and in any site belonging to you, the most recent articles published on this site.',
'ical_texte_prive' => 'This calendar, which is strictly personal, informs you of the private editorial ativity of this site (tasks, personal appointements, submitted articles and news items...).',
'ical_texte_public' => 'This calendar allows you to follow the public activity of this site (published articles and news items).',
'ical_texte_rss' => 'You can syndicate the latest news of this site in any XML/RSS (Rich Site Summary) files reader. This is also the format that allows SPIP to read the latest news published by other sites using a compatible exchange format (syndicated sites).',
'ical_titre_js' => 'Javascript',
'ical_titre_mailing' => 'Mailing-list',
'ical_titre_rss' => 'Syndication files',
'icone_activer_cookie' => 'Place a cookie',
'icone_admin_plugin' => 'Manage plugins',
'icone_afficher_auteurs' => 'Show authors',
'icone_afficher_visiteurs' => 'Show visitors',
'icone_arret_discussion' => 'Stop participating in this discussion',
'icone_calendrier' => 'Calendar',
'icone_creation_groupe_mots' => 'Create a new keyword group',
'icone_creation_mots_cles' => 'Create a new keyword',
'icone_creer_auteur' => 'Create a new author and associate him with this article',
'icone_creer_mot_cle' => 'Create a new keyword and link it to this article',
'icone_creer_mot_cle_breve' => 'Create a new keyword and attach it to this news item',
'icone_creer_mot_cle_rubrique' => 'Create a new keyword and attach it to this section',
'icone_creer_mot_cle_site' => 'Create a new keyword and attach it to this site',
'icone_creer_rubrique_2' => 'Create a new section',
'icone_ecrire_nouvel_article' => 'News in this section',
'icone_envoyer_message' => 'Send this message',
'icone_evolution_visites' => 'Visits level<br />@visites@ visits',
'icone_modif_groupe_mots' => 'Modify this keyword group',
'icone_modifier_article' => 'Modify this article',
'icone_modifier_breve' => 'Modify this news item',
'icone_modifier_message' => 'Modify this message',
'icone_modifier_mot' => 'Edit this keyword',
'icone_modifier_rubrique' => 'Modify this section',
'icone_modifier_site' => 'Modify this site',
'icone_poster_message' => 'Post a message',
'icone_publier_breve' => 'Publish this news item',
'icone_referencer_nouveau_site' => 'Reference a new site',
'icone_refuser_breve' => 'Reject this news item',
'icone_relancer_signataire' => 'Contact the signatory again',
'icone_retour' => 'Back',
'icone_retour_article' => 'Back to the article',
'icone_suivi_forum' => 'Follow-up of public forum: @nb_forums@ contribution(s)',
'icone_supprimer_cookie' => 'Delete cookie',
'icone_supprimer_groupe_mots' => 'Delete this group',
'icone_supprimer_rubrique' => 'Delete this section',
'icone_supprimer_signature' => 'Delete this signature',
'icone_valider_signature' => 'Validate this signature',
'icone_voir_sites_references' => 'Show referenced sites',
'icone_voir_tous_mots_cles' => 'Show all keywords',
'image_administrer_rubrique' => 'You can manage this section',
'info_1_article' => '1 article',
'info_1_breve' => '1 news item',
'info_1_site' => '1 site',
'info_activer_cookie' => 'You can activate an <b>administration cookie</b>, which allows you
 to switch easily between the public site and the private area.',
'info_activer_forum_public' => '<i>To enable public forums, please choose their default mode of moderation:</i>',
'info_admin_gere_rubriques' => 'This administrator manages the following sections:',
'info_admin_gere_toutes_rubriques' => 'This administrator manages <b>all the sections</b>.',
'info_admin_statuer_webmestre' => 'Give webmaster rights to this administrator ',
'info_admin_webmestre' => 'This administrator is <b>webmaster</b>',
'info_administrateur' => 'Administrator',
'info_administrateur_1' => 'Administrator',
'info_administrateur_2' => 'of the site (<i>use with caution</i>)',
'info_administrateur_site_01' => 'If you are a site administrator, please',
'info_administrateur_site_02' => 'click on this link',
'info_administrateurs' => 'Administrators',
'info_administrer_rubrique' => 'You can manage this section',
'info_adresse' => 'to the address:',
'info_adresse_email' => 'E-MAIL ADDRESS:',
'info_adresse_url' => 'Your public site\'s URL',
'info_afficher_visites' => 'Show visits for:',
'info_affichier_visites_articles_plus_visites' => 'Show visits for <b>the most visited articles since the beginning:</b>',
'info_aide_en_ligne' => 'SPIP Online Help',
'info_ajout_image' => 'When you add images as attached documents to an article,
  SPIP can automatically create thumbnails from
  inserted images. This will allow, for instance, the automated
  creation of a gallery or a portfolio.',
'info_ajout_participant' => 'The following participant has been added:',
'info_ajouter_rubrique' => 'Add another section to manage:',
'info_annonce_nouveautes' => 'Latest news announcements',
'info_anterieur' => 'previous',
'info_appliquer_choix_moderation' => 'Apply this choice of moderation:',
'info_article' => 'article',
'info_article_2' => 'articles',
'info_article_a_paraitre' => 'Post-dated articles to be published',
'info_articles_02' => 'articles',
'info_articles_2' => 'Articles',
'info_articles_auteur' => 'This author\'s articles',
'info_articles_lies_mot' => 'Articles associated with this keyword',
'info_articles_trouves' => 'Articles found',
'info_articles_trouves_dans_texte' => 'Articles found (in the text)',
'info_attente_validation' => 'Your articles pending validation',
'info_aujourdhui' => 'today:',
'info_auteur_message' => 'MESSAGE SENDER:',
'info_auteurs' => 'Authors',
'info_auteurs_par_tri' => 'Authors@partri@',
'info_auteurs_trouves' => 'Authors found',
'info_authentification_externe' => 'External authentication',
'info_avertissement' => 'Warning',
'info_barre_outils' => 'with its toolbar?',
'info_base_installee' => 'The structure of your database is installed.',
'info_base_restauration' => 'Restoration of the database in progress.',
'info_bloquer' => 'block',
'info_breves' => 'Does your site use the news system?',
'info_breves_03' => 'news items',
'info_breves_liees_mot' => 'News associated with this keyword',
'info_breves_touvees' => 'News items found',
'info_breves_touvees_dans_texte' => 'News items found (in the text)',
'info_changer_nom_groupe' => 'Change the name of this group:',
'info_chapeau' => 'Standfirst',
'info_chapeau_2' => 'Introduction:',
'info_chemin_acces_1' => 'Options: <b>Access path in directory</b>',
'info_chemin_acces_2' => 'From now on, you have to configure the access path to the directory information. This information is essential to read the users profiles stored in the directory.',
'info_chemin_acces_annuaire' => 'Options: <b>Access path in directory</b>',
'info_choix_base' => 'Third step:',
'info_classement_1' => '&nbsp;out of @liste@',
'info_classement_2' => '&nbsp;out of @liste@',
'info_code_acces' => 'Do not forget your own access codes!',
'info_comment_lire_tableau' => 'How to read this graphic',
'info_compresseur_gzip' => 'It is advisable to first check if the service provider systematically compresses PHP scripts. To do this you can, for example, use the following service: @testgzip@',
'info_compresseur_texte' => 'If your server does not automatically compress HTML pages when sending them, you can attempt to force the compression in order to reduce the size of the pages transmitted.<b>Warning</b>: this can have a noticeable adverse effect on the performance of some servers, ',
'info_compresseur_titre' => 'Optimisations and compression',
'info_config_forums_prive' => 'In the editing area of the site several differnt kinds of forum may be activated:',
'info_config_forums_prive_admin' => 'A forum reserved for site administrators:',
'info_config_forums_prive_global' => 'A global forum, open to all the authors:',
'info_config_forums_prive_objets' => 'A forum attached to each article, news item, referenced site, etc.:',
'info_config_suivi' => 'If this address corresponds to a mailing list, you can indicate below the address where the site\'s participants can register. This address could be a URL (for instance the page of the list registration via the web), or an e-mail address with a specific subject (for instance: <tt>@adresse_suivi@?subject=subscribe</tt>):',
'info_config_suivi_explication' => 'You can subscribe to the mailing-list of this site. You will receive then, by automated electronic mail, the announcements concerning articles and news items submitted for publication.',
'info_confirmer_passe' => 'Confirm new password:',
'info_conflit_edition_avis_non_sauvegarde' => 'Caution: the following fields have been modified elsewhere. Your changes to these fields have therefore not been saved.',
'info_conflit_edition_differences' => 'Differences:',
'info_conflit_edition_version_enregistree' => 'Saved version:',
'info_conflit_edition_votre_version' => 'Your version:',
'info_connexion_base' => 'Trying to connect to database',
'info_connexion_base_donnee' => 'Connection to your database',
'info_connexion_ldap_ok' => 'Your LDAP connection succeeded.</b><p> You can go to the next step.</p>',
'info_connexion_mysql' => 'Your SQL connection',
'info_connexion_ok' => 'Connection succeeded.',
'info_contact' => 'Contact',
'info_contenu_articles' => 'Articles content',
'info_creation_mots_cles' => 'Create and configure the site\'s keywords here',
'info_creation_paragraphe' => '(To create paragraphs, you simply leave blank lines.)',
'info_creation_rubrique' => 'Before being able to write articles,<br /> you must create at least one section.<br />',
'info_creation_tables' => 'Creating the database tables',
'info_creer_base' => '<b>Create</b> a new database:',
'info_dans_groupe' => 'In group:',
'info_dans_rubrique' => 'In section:',
'info_date_publication_anterieure' => 'Date of earlier publishing:',
'info_date_referencement' => 'DATE OF REFERENCING THIS SITE:',
'info_delet_mots_cles' => 'You requested the deletion of keyword
<b>@titre_mot@</b> (@type_mot@). This keyword being linked to
<b>@texte_lie@</b>you must confirm this decision:',
'info_derniere_etape' => 'Done!',
'info_derniere_syndication' => 'The last syndication of this site was carried out on',
'info_derniers_articles_publies' => 'Your latest published articles',
'info_desactiver_forum_public' => 'Disable the use of public
	forums. Public forums could be allowed on a case by case
	basis for the articles; they will be forbidden for the sections, news, etc.',
'info_desactiver_messagerie_personnelle' => 'You can enable or disable your personal messaging on this site.',
'info_descriptif' => 'Description:',
'info_desinstaller_plugin' => 'deletes the data and deactivates the plugin',
'info_discussion_cours' => 'Discussions in progress',
'info_ecrire_article' => 'Before being able to write articles, you must create at least one section.',
'info_email_envoi' => 'The sender\'s email address (optional)',
'info_email_envoi_txt' => 'Enter the sender\'s email address used while sending the emails (by default, the recipient\'s address is used as the sender\'s address)&nbsp;:',
'info_email_webmestre' => 'Webmaster\'s e-mail address (optional)',
'info_entrer_code_alphabet' => 'Enter the code of the character set to be used:',
'info_envoi_email_automatique' => 'Automated mailing',
'info_envoi_forum' => 'Send forums to articles authors',
'info_envoyer_maintenant' => 'Send now',
'info_erreur_restauration' => 'Restoration error: file not found.',
'info_etape_suivante' => 'Go to the next step',
'info_etape_suivante_1' => 'You can move to the next step.',
'info_etape_suivante_2' => 'You can move to the next step.',
'info_exportation_base' => 'export database to @archive@',
'info_facilite_suivi_activite' => 'To facilitate the follow-up of the site\'s editorial;
  activities, SPIP can send notification by email, to an editor\'s mailing list for instance,
  of publication requests and article validations.',
'info_fichiers_authent' => 'Authentication file ".htpasswd"',
'info_fonctionnement_forum' => 'Forum operation:',
'info_forum_administrateur' => 'administrators\' forum',
'info_forum_interne' => 'internal forum',
'info_forum_ouvert' => 'In the site\'s private area, a forum is open to all
		registered editors. Below, you can enable an
		extra forum reserved for the administrators.',
'info_forum_statistiques' => 'Visits statistics',
'info_forums_abo_invites' => 'Your site contains forums by subscription; visitors may register for them on the public site.',
'info_gauche_admin_effacer' => '<b>Only webmasters have access to this page.</b><p> It provides access to various technical maintenance tasks. Some of them require a specific authentication process through an FTP access to the Web site.</p>',
'info_gauche_admin_tech' => '<b>Only webmasters have access to this page.</b><p> It provides access to various
maintenance tasks. Some of them require a specific authentication process
through an FTP access to the Web site.</p>',
'info_gauche_admin_vider' => '<b>Only webmasters have access to this page.</b><p> It provides access to various
maintenance tasks. Some of them require a specific authentication process
through an FTP access to the Web site.</p>',
'info_gauche_auteurs' => 'You will find here all the site\'s authors.
 The status of each one is indicated by the colour of there icon (administrator = green; editor = yellow).',
'info_gauche_auteurs_exterieurs' => 'External authors, without any access to the site, are indicated by a blue icon; deleted authors by a dustbin.',
'info_gauche_messagerie' => 'Messaging allows you to exchange messages amongst editors, to preserve memos (for your personal use) or to display announcements on the homepage of the private area (if you are an administrator).',
'info_gauche_numero_auteur' => 'AUTHOR NUMBER:',
'info_gauche_numero_breve' => 'NEWS ITEM NUMBER',
'info_gauche_statistiques_referers' => 'This page displays the list of <i>referrers</i>, i.e. the sites containing links to your own site, only for yesteday and today: actually this list is initialised every 24 hours.',
'info_gauche_suivi_forum' => 'The <i>forums follow-up</i> page is a management tool of your site (not a discussion or editing area). It displays all the contributions of the public forum of this article and allows you to manage these contributions.',
'info_gauche_suivi_forum_2' => 'The <i>forums follow-up</i> page is a management tool of your site (not a discussion or editing). It displays all contributions to the forums (both of the public site and of the private area) and allows you to manage these contributions.',
'info_gauche_visiteurs_enregistres' => 'You will find here the visitors registered
	in the public area of the site (forums by subscription).',
'info_generation_miniatures_images' => 'Generation of thumbnail images',
'info_gerer_trad' => 'Enable translation links?',
'info_groupe_important' => 'Important group',
'info_hebergeur_desactiver_envoi_email' => 'Some hosts disable automated mail sending
		on their servers. In this case the following features
		of SPIP cannot be implemented.',
'info_hier' => 'yesterday:',
'info_historique' => 'Revisions:',
'info_historique_activer' => 'Enable revision tracking',
'info_historique_affiche' => 'Display this version',
'info_historique_comparaison' => 'compare',
'info_historique_desactiver' => 'Disable revision tracking',
'info_historique_lien' => 'Display list of versions',
'info_historique_texte' => 'Revision tracking allows you to see the changes and additions made to an article and displays the differences between successive versions.',
'info_historique_titre' => 'Revision tracking',
'info_identification_publique' => 'Your public identity...',
'info_image_process' => 'Select the best method to create thumbnails by clicking on the corresponding picture.',
'info_image_process2' => '<b>N.B.</b> <i>If you can\'t see any image, then your server is not configured to use such tools. If you want to use these features, contact your provider\'s technical support and ask for the &laquo;GD&raquo; or &laquo;Imagick&raquo; extensions to be installed.</i>',
'info_images_auto' => 'Images automatically calculated',
'info_informations_personnelles' => 'Personal information',
'info_inscription_automatique' => 'Automated registration of new editors',
'info_jeu_caractere' => 'Character set of the site',
'info_jours' => 'days',
'info_laisser_champs_vides' => 'leave these fields empty)',
'info_langues' => 'The site\'s languages',
'info_ldap_ok' => 'LDAP authentication is installed.',
'info_lien_hypertexte' => 'Hyperlink:',
'info_liens_syndiques_1' => 'syndicated links',
'info_liens_syndiques_2' => 'pending validation.',
'info_liens_syndiques_3' => 'forums',
'info_liens_syndiques_4' => 'are',
'info_liens_syndiques_5' => 'forum',
'info_liens_syndiques_6' => 'is',
'info_liens_syndiques_7' => 'pending validation.',
'info_liste_redacteurs_connectes' => 'List of connected editors',
'info_login_existant' => 'This login already exists.',
'info_login_trop_court' => 'Login too short.',
'info_logos' => 'The logos',
'info_maximum' => 'maximum:',
'info_meme_rubrique' => 'In the same section',
'info_message' => 'Message from',
'info_message_efface' => 'MESSAGE DELETED',
'info_message_en_redaction' => 'Your messages in progress',
'info_message_technique' => 'Technical message:',
'info_messagerie_interne' => 'Internal messaging',
'info_mise_a_niveau_base' => 'SQL database upgrade',
'info_mise_a_niveau_base_2' => '{{Warning!}} You have installed a version of
  SPIP files {older} than the one
  previously installed on this site: your database is at risk of being lost
  and your site will not work properly anymore.<br />{{Reinstall
  SPIP files.}}',
'info_mode_fonctionnement_defaut_forum_public' => 'Default operation mode of public forums',
'info_modifier_auteur' => 'Edit author details:',
'info_modifier_breve' => 'Modify the news item:',
'info_modifier_mot' => 'Edit the keyword:',
'info_modifier_rubrique' => 'Modify the section:',
'info_modifier_titre' => 'Modify: @titre@',
'info_mon_site_spip' => 'My SPIP site',
'info_mot_sans_groupe' => '(Keywords without a group...)',
'info_moteur_recherche' => 'Integrated search engine',
'info_mots_cles' => 'Keywords',
'info_mots_cles_association' => 'Keywords in this group can be associated with:',
'info_moyenne' => 'average:',
'info_multi_articles' => 'Enable the language menu for the articles?',
'info_multi_cet_article' => 'Language of this article:',
'info_multi_langues_choisies' => 'Please select below the languages to be available to the editors of your site.
  Languages already used by your site (on top of the list) cannot be disabled.',
'info_multi_rubriques' => 'Enable the language menu for the sections?',
'info_multi_secteurs' => '... only for the sections located at the root?',
'info_nom' => 'Name',
'info_nom_destinataire' => 'Name of recipient',
'info_nom_site' => 'Your site\'s name',
'info_nom_site_2' => '<b>Site name</b> [Required]',
'info_nombre_articles' => '@nb_articles@ articles,',
'info_nombre_breves' => '@nb_breves@ news items,',
'info_nombre_partcipants' => 'PARTICIPANTS TO THE DISCUSSION:',
'info_nombre_rubriques' => '@nb_rubriques@ sections,',
'info_nombre_sites' => '@nb_sites@ sites,',
'info_non_deplacer' => 'Do not move...',
'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP can send the site\'s latest news announcements regularly.
		(recently published articles and news).',
'info_non_envoi_liste_nouveautes' => 'Do not send latest news list',
'info_non_modifiable' => 'cannot be modified',
'info_non_suppression_mot_cle' => 'I do not want to delete this keyword.',
'info_notes' => 'Footnotes',
'info_nouveaux_message' => 'New messages',
'info_nouvel_article' => 'New article',
'info_nouvelle_traduction' => 'New translation:',
'info_numero_article' => 'ARTICLE NUMBER:',
'info_obligatoire_02' => '[Required]',
'info_option_accepter_visiteurs' => 'Allow visitors registration from the public site',
'info_option_email' => 'When a visitor posts a message to the forum associated with an article, the article\'s authors can be informed of this message by email. Indicate for each type of forum if this option should be activated.',
'info_option_faire_suivre' => 'Forward forums messages to articles authors',
'info_option_ne_pas_accepter_visiteurs' => 'Refuse visitor registration',
'info_option_ne_pas_faire_suivre' => 'Do not forward forums messages',
'info_options_avancees' => 'ADVANCED OPTIONS',
'info_ortho_activer' => 'Enable the spell checker.',
'info_ortho_desactiver' => 'Disable the spell checker.',
'info_ou' => 'or...',
'info_oui_suppression_mot_cle' => 'I want to delete this keyword permanently.',
'info_page_interdite' => 'Forbidden page',
'info_par_nom' => 'by name',
'info_par_nombre_article' => 'by number of articles',
'info_par_statut' => 'by status',
'info_par_tri' => '\'(by @tri@)\'',
'info_pas_de_forum' => 'no forum',
'info_passe_trop_court' => 'Password too short.',
'info_passes_identiques' => 'The two passwords are not identical.',
'info_pense_bete_ancien' => 'Your old memos',
'info_plus_cinq_car' => 'more than 5 characters',
'info_plus_cinq_car_2' => '(More than 5 characters)',
'info_plus_trois_car' => '(More than 3 characters)',
'info_popularite' => 'popularity: @popularite@; visits: @visites@',
'info_popularite_2' => 'site popularity:',
'info_popularite_3' => 'popularity:&nbsp;@popularite@; visits:&nbsp;@visites@',
'info_popularite_4' => 'popularity:&nbsp;@popularite@; visits:&nbsp;@visites@',
'info_post_scriptum' => 'Postscript',
'info_post_scriptum_2' => 'Postscript:',
'info_pour' => 'for',
'info_preview_admin' => 'Only administrators have access to the preview mode',
'info_preview_comite' => 'All authors have access to the preview mode',
'info_preview_desactive' => 'Preview mode is disabled',
'info_preview_texte' => 'It is possible to preview the site as if all articles and news items (which have at least the status "submitted") were already published. Should this preview mode be restricted to administrators, open to all authors, or disabled completely?',
'info_principaux_correspondants' => 'Your main correspondents',
'info_procedez_par_etape' => 'please proceed step by step',
'info_procedure_maj_version' => 'the upgrade procedure should be ran to adapt
	the database to the new version of SPIP.',
'info_proxy_ok' => 'Test of the proxy successful.',
'info_ps' => 'P.S.',
'info_publier' => 'publish',
'info_publies' => 'Your articles published online',
'info_question_accepter_visiteurs' => 'If your site\'s templates allow visitors to register without entering the private area, please activate the following option:',
'info_question_activer_compactage_css' => 'Do you wish to activate compression for CSS stylesheets?',
'info_question_activer_compactage_js' => 'Do you wish to activate compression for Javascript files?',
'info_question_activer_compresseur' => 'Do you wish to activate compression for the HTTP data?',
'info_question_gerer_statistiques' => 'Should your site manage visits statistics?',
'info_question_inscription_nouveaux_redacteurs' => 'Do you wish to allow the new editors to register
 from the public site? If you agree to this, visitors will be able to  register
  using an automatic form, and then access the private area to
  tender their own articles. <blockquote><i>During the registration process,
  users receive an automatic email
  giving them their access code to the private area. Some
  service providers disallow the sending of email from their
  servers: in that case, automated registration cannot be
  implemented.</i></blockquote>',
'info_question_mots_cles' => 'Do you wish to use keywords in your site?',
'info_question_proposer_site' => 'Who can propose referenced sites?',
'info_question_utilisation_moteur_recherche' => 'Do you wish to use the search engine integrated to SPIP?
	(Disabling it speeds up the performance of the system.)',
'info_question_vignettes_referer' => 'When you consult the statistics, you can see a preview of the originating sites of the visits. ',
'info_question_vignettes_referer_non' => 'Do not show the screenshots of the originating sites',
'info_question_vignettes_referer_oui' => 'Show the screenshots of the originating sites',
'info_question_visiteur_ajout_document_forum' => 'If you wish to allow visitors to attach documents (images, sound files, ...) to their forum messages, indicate below the list of file extensions which are authorised (e.g. gif, jpg, png, mp3).',
'info_question_visiteur_ajout_document_forum_format' => 'If you wish to authorise all document types which SPIP allows, then put an asterisk. To allow no file-types, leave empty.',
'info_qui_attribue_mot_cle' => 'Keywords in this group can be assigned by:',
'info_racine_site' => 'Site root',
'info_recharger_page' => 'Please reload this page in a few moments.',
'info_recherche_auteur_a_affiner' => 'Too many results for "@cherche_auteur@"; please refine your search.',
'info_recherche_auteur_ok' => 'Several editors were found for "@cherche_auteur@":',
'info_recherche_auteur_zero' => 'No results for "@cherche_auteur@".',
'info_recommencer' => 'Please try again.',
'info_redacteur_1' => 'R&eacute;dacteur',
'info_redacteur_2' => 'having access to the private area (<i>recommended</i>)',
'info_redacteurs' => 'Editors',
'info_redaction_en_cours' => 'EDITING IN PROGRESS',
'info_redirection' => 'Redirection',
'info_referencer_doc_distant' => 'Reference a document on the internet:',
'info_refuses' => 'Your articles rejected',
'info_reglage_ldap' => 'Options: <b>Adjusting LDAP import</b>',
'info_renvoi_article' => '<b>Redirection.</b> This article redirects to:',
'info_reserve_admin' => 'Only administrators can modify this address.',
'info_restauration_sauvegarde' => 'Restoring the backup @archive@',
'info_restauration_sauvegarde_insert' => 'Inserting @archive@ in the database',
'info_restreindre_rubrique' => 'Restrict management to section:',
'info_resultat_recherche' => 'Search results:',
'info_rubriques' => 'Sections',
'info_rubriques_02' => 'sections',
'info_rubriques_liees_mot' => 'Sections associated with this keyword',
'info_rubriques_trouvees' => 'Sections found',
'info_rubriques_trouvees_dans_texte' => 'Sections found (in the text)',
'info_sans_titre' => 'Untitled',
'info_sauvegarde' => 'Backup',
'info_sauvegarde_articles' => 'Backup the articles',
'info_sauvegarde_articles_sites_ref' => 'Backup articles of referenced sites',
'info_sauvegarde_auteurs' => 'Backup the authors',
'info_sauvegarde_breves' => 'Backup the news',
'info_sauvegarde_documents' => 'Backup the documents',
'info_sauvegarde_echouee' => 'If the backup fails (&laquo;Maximum execution time exceeded&raquo;),',
'info_sauvegarde_forums' => 'Backup the forums',
'info_sauvegarde_groupe_mots' => 'Backup keyword groups',
'info_sauvegarde_messages' => 'Backup the messages',
'info_sauvegarde_mots_cles' => 'Backup the keywords',
'info_sauvegarde_petitions' => 'Backup the petitions',
'info_sauvegarde_refers' => 'Backup the referrers',
'info_sauvegarde_reussi_01' => 'Backup successful.',
'info_sauvegarde_reussi_02' => 'The database has been saved in @archive@. You can',
'info_sauvegarde_reussi_03' => 'return to the management',
'info_sauvegarde_reussi_04' => 'of your site.',
'info_sauvegarde_rubrique_reussi' => 'The tables of the @titre@ section have been saved to @archive@. You can',
'info_sauvegarde_rubriques' => 'Backup the sections',
'info_sauvegarde_signatures' => 'Backup petitions signatures',
'info_sauvegarde_sites_references' => 'Backup referenced sites',
'info_sauvegarde_type_documents' => 'Backup documents types',
'info_sauvegarde_visites' => 'Backup the visits',
'info_selection_chemin_acces' => '<b>Select</b> below the access path in the directory:',
'info_selection_un_seul_mot_cle' => 'You can select <b>only one keyword</b> at a time in this group.',
'info_signatures' => 'signatures',
'info_site' => 'Site',
'info_site_2' => 'site:',
'info_site_min' => 'site',
'info_site_propose' => 'Site submitted on:',
'info_site_reference_2' => 'Referenced site',
'info_site_syndique' => 'This site is syndicated...',
'info_site_valider' => 'Sites to be validated',
'info_site_web' => 'WEB SITE:',
'info_sites' => 'sites',
'info_sites_lies_mot' => 'Referenced sites associated with this keyword',
'info_sites_proxy' => 'Using a proxy',
'info_sites_refuses' => 'Rejected sites',
'info_sites_trouves' => 'Sites found',
'info_sites_trouves_dans_texte' => 'Sites found (in the text)',
'info_sous_titre' => 'Subtitle:',
'info_statut_administrateur' => 'Administrator',
'info_statut_auteur' => 'This author\'s status:',
'info_statut_auteur_a_confirmer' => 'Registration to be confirmed',
'info_statut_auteur_autre' => 'Other status:',
'info_statut_efface' => 'Deleted',
'info_statut_redacteur' => 'Editor',
'info_statut_site_1' => 'This site is:',
'info_statut_site_2' => 'Published',
'info_statut_site_3' => 'Submitted',
'info_statut_site_4' => 'In the dustbin',
'info_statut_utilisateurs_1' => 'Default status of imported users',
'info_statut_utilisateurs_2' => 'Choose the status that is attributed to the persons present in the LDAP directory when they connect for the first time. Later, you can modify this value for each author on a case by case basis.',
'info_suivi_activite' => 'Follow-up of editorial activity',
'info_supprimer_mot' => 'delete this keyword',
'info_surtitre' => 'Top title:',
'info_syndication_integrale_1' => 'Your site offers syndication files (see &#147;<a href="@url@">@titre@</a>&#148;).',
'info_syndication_integrale_2' => 'Do you wish to send whole articles or only a summary of a few hundred characters?',
'info_table_prefix' => 'It is possible to change the prefix of the names of the database tables. (you need to do this if you are installing several sites in the same database). The prefix must be written in unaccented, lower-case letters without any spaces.',
'info_taille_maximale_images' => 'SPIP is going to test the maximum size of image (in millions of pixels) which it can treat.<br /> Images bigger than this will not be reduced.',
'info_taille_maximale_vignette' => 'Maximum size of vignettes generated by the system:',
'info_terminer_installation' => 'You can now finish the standard installation process.',
'info_texte' => 'Text',
'info_texte_explicatif' => 'Explanatory text',
'info_texte_long' => '(The text is long: it will appear in several parts which will be reassembled after validation.)',
'info_texte_message' => 'Text of your message:',
'info_texte_message_02' => 'Text of message',
'info_titre' => 'Title:',
'info_titre_mot_cle' => 'Name or title of this keyword',
'info_total' => 'total:',
'info_tous_articles_en_redaction' => 'All the articles in progress',
'info_tous_articles_presents' => 'All the articles published in this section',
'info_tous_articles_refuses' => 'All refused articles',
'info_tous_les' => 'every:',
'info_tous_redacteurs' => 'Announcements to all editors',
'info_tout_site' => 'The entire site',
'info_tout_site2' => 'The article has not been translated into this language.',
'info_tout_site3' => 'The article has been translated into this language, but some changes have been made afterwards to the reference article. The translation needs updating.',
'info_tout_site4' => 'The article has been translated into this language, and the translation is up-to-date.',
'info_tout_site5' => 'Original article.',
'info_tout_site6' => '<b>Warning:</b> only original articles are displayed.
The translations are associated with the original,
in a colour indicating their status:',
'info_travail_colaboratif' => 'Collaborative work on articles',
'info_un_article' => 'an article,',
'info_un_mot' => 'One keyword at a time',
'info_un_site' => 'a site,',
'info_une_breve' => 'a news item,',
'info_une_rubrique' => 'a section,',
'info_une_rubrique_02' => '1 section',
'info_url' => 'URL:',
'info_url_site' => 'SITE\'S URL:',
'info_urlref' => 'Hyperlink:',
'info_utilisation_spip' => 'SPIP is now ready to be used...',
'info_visites_par_mois' => 'Monthly display:',
'info_visites_plus_populaires' => 'Show visits for <b>the most popular articles</b> and for <b>the last published articles:</b>',
'info_visiteur_1' => 'Visitor',
'info_visiteur_2' => 'of the public site',
'info_visiteurs' => 'Visitors',
'info_visiteurs_02' => 'Public site visitors',
'install_adresse_base_hebergeur' => 'Database address attributed by the service provider',
'install_base_ok' => 'The base @base@ was identified',
'install_echec_annonce' => 'This installation will probably not work, or will result in a nonfunctional site...',
'install_extension_mbstring' => 'SPIP does not work with:',
'install_extension_php_obligatoire' => 'SPIP requires a php extension:',
'install_login_base_hebergeur' => 'Login attributed by the service provider',
'install_nom_base_hebergeur' => 'Database name attributed by the service provider:',
'install_pas_table' => 'The database has no table yet',
'install_pass_base_hebergeur' => 'Connection password attributed by the service provider',
'install_php_version' => 'The PHP version @version@ is too old (minimum = @minimum@)',
'install_select_langue' => 'Select a language then click on the button "next" to start the installation procedure.',
'install_select_type_db' => 'Indicate the type of database:',
'install_select_type_mysql' => 'MySQL',
'install_select_type_pg' => 'PostgreSQL',
'install_select_type_sqlite2' => 'SQLite 2',
'install_select_type_sqlite3' => 'SQLite 3',
'install_serveur_hebergeur' => 'Database server attributed by the service provider',
'install_table_prefix_hebergeur' => 'Table prefix attributed by the service provider:',
'install_tables_base' => 'Tables of the database',
'install_types_db_connus' => 'SPIP can use <b>MySQL</b> (the most common), <b>PostgreSQL</b> and <b>SQLite</b>.',
'install_types_db_connus_avertissement' => 'N.B.: some plugins only function with MySQL',
'intem_redacteur' => 'editor',
'intitule_licence' => 'License',
'item_accepter_inscriptions' => 'Allow registrations',
'item_activer_forum_administrateur' => 'Enable administrators forum',
'item_activer_messages_avertissement' => 'Activate warning messages',
'item_administrateur_2' => 'administrator',
'item_afficher_calendrier' => 'Display in calendar',
'item_ajout_mots_cles' => 'Authorise the addition of keywords to forums',
'item_autoriser_documents_joints' => 'Authorise documents attached to articles',
'item_autoriser_documents_joints_rubriques' => 'Authorise documents in the sections',
'item_autoriser_selectionner_date_en_ligne' => 'Allow changes to the date of each document',
'item_autoriser_syndication_integrale' => 'Include entire articles in the syndication files',
'item_bloquer_liens_syndiques' => 'Block syndicated links for validation',
'item_breve_refusee' => 'NO - News item rejected',
'item_breve_validee' => 'YES - News item validated',
'item_choix_administrateurs' => 'administrators',
'item_choix_generation_miniature' => 'Generate thumbnails automatically.',
'item_choix_non_generation_miniature' => 'Do not generate thumbnails.',
'item_choix_redacteurs' => 'editors',
'item_choix_visiteurs' => 'visitors of the public site',
'item_compresseur' => 'Activate compression',
'item_config_forums_prive_global' => 'Activate the authors\' forum',
'item_config_forums_prive_objets' => 'Activate these forums',
'item_creer_fichiers_authent' => 'Create .htpasswd files',
'item_desactiver_forum_administrateur' => 'Disable administrators forum',
'item_gerer_annuaire_site_web' => 'Manage Web sites directory',
'item_gerer_statistiques' => 'Manage statistics',
'item_limiter_recherche' => 'Limit the search to information contained in your site',
'item_login' => 'Login',
'item_messagerie_agenda' => 'Activate the messaging sytem and the calendar',
'item_mots_cles_association_articles' => 'articles',
'item_mots_cles_association_breves' => 'news items',
'item_mots_cles_association_rubriques' => 'sections',
'item_mots_cles_association_sites' => 'referenced or syndicated sites.',
'item_non' => 'No',
'item_non_accepter_inscriptions' => 'Do not allow registrations',
'item_non_activer_messages_avertissement' => 'No warning messages',
'item_non_afficher_calendrier' => 'Do not display in calendar',
'item_non_ajout_mots_cles' => 'Do not authorise the addition of keywords to forums',
'item_non_autoriser_documents_joints' => 'Do not authorise documents in articles',
'item_non_autoriser_documents_joints_rubriques' => 'Do not authorise documents in the sections',
'item_non_autoriser_selectionner_date_en_ligne' => 'The date of a document is the date it was added to the site',
'item_non_autoriser_syndication_integrale' => 'Only send a summary',
'item_non_bloquer_liens_syndiques' => 'Do not block the links emanating from syndication',
'item_non_compresseur' => 'Deactivate compression',
'item_non_config_forums_prive_global' => 'Deactivate the authors\' forum',
'item_non_config_forums_prive_objets' => 'Deactivate these forums',
'item_non_creer_fichiers_authent' => 'Do not create these files',
'item_non_gerer_annuaire_site_web' => 'Disable Web sites directory',
'item_non_gerer_statistiques' => 'Do not manage statistics',
'item_non_limiter_recherche' => 'Extend the search to the content of referenced sites',
'item_non_messagerie_agenda' => 'Deactivate the messaging system and the calendar',
'item_non_publier_articles' => 'Do not publish the articles before their publication dates.',
'item_non_utiliser_breves' => 'Do not use the news',
'item_non_utiliser_config_groupe_mots_cles' => 'Do not use the advanced configuration of keyword groups',
'item_non_utiliser_moteur_recherche' => 'Do not use the engine',
'item_non_utiliser_mots_cles' => 'Do not use keywords',
'item_non_utiliser_syndication' => 'Do not use automated syndication',
'item_nouvel_auteur' => 'New author',
'item_nouvelle_breve' => 'New news item',
'item_nouvelle_rubrique' => 'New section',
'item_oui' => 'Yes',
'item_publier_articles' => 'Publish the articles disregarding their publication dates.',
'item_reponse_article' => 'Reply to the article',
'item_utiliser_breves' => 'Use the news',
'item_utiliser_config_groupe_mots_cles' => 'Use the advanced configuration of keyword groups',
'item_utiliser_moteur_recherche' => 'Use the search engine',
'item_utiliser_mots_cles' => 'Use keywords',
'item_utiliser_syndication' => 'Use automated syndication',
'item_visiteur' => 'visitor',

// J
'jour_non_connu_nc' => 'unknown',

// L
'lien_ajout_destinataire' => 'Add this recipient',
'lien_ajouter_auteur' => 'Add this author',
'lien_ajouter_participant' => 'Add a participant',
'lien_email' => 'e-mail',
'lien_forum_public' => 'Manage this article\'s public forum',
'lien_mise_a_jour_syndication' => 'Update now',
'lien_nom_site' => 'SITE\'S NAME:',
'lien_nouvelle_recuperation' => 'Try to perform a new retrieval of data',
'lien_reponse_article' => 'Reply to the article',
'lien_reponse_breve' => 'Reply to the news item',
'lien_reponse_breve_2' => 'Reply to the news item',
'lien_reponse_rubrique' => 'Reply to the section',
'lien_reponse_site_reference' => 'Reply to the referenced site:',
'lien_retirer_auteur' => 'Remove author',
'lien_retrait_particpant' => 'remove this participant',
'lien_site' => 'site',
'lien_supprimer_rubrique' => 'delete this section',
'lien_tout_deplier' => 'Expand all',
'lien_tout_replier' => 'Collapse all',
'lien_tout_supprimer' => 'Delete all',
'lien_trier_nom' => 'Sort by name',
'lien_trier_nombre_articles' => 'Sort by number of articles',
'lien_trier_statut' => 'Sort by status',
'lien_voir_en_ligne' => 'VIEW ONLINE:',
'logo_article' => 'ARTICLE\'S LOGO',
'logo_auteur' => 'AUTHOR\'S LOGO',
'logo_breve' => 'NEWS ITEM\'S LOGO',
'logo_mot_cle' => 'KEYWORD\'S LOGO',
'logo_rubrique' => 'SECTION\'S LOGO',
'logo_site' => 'THIS SITE\'S LOGO',
'logo_standard_rubrique' => 'STANDARD LOGO FOR SECTIONS',
'logo_survol' => 'HOVERING LOGO',

// M
'menu_aide_installation_choix_base' => 'Choosing your database',
'module_fichier_langue' => 'Language file',
'module_raccourci' => 'Shortcut',
'module_texte_affiche' => 'Displayed text',
'module_texte_explicatif' => 'You can insert the following shortcuts in you site\'s templates. They will be automatically translated in the various languages for which there is a language file.',
'module_texte_traduction' => 'The language file &laquo;&nbsp;@module@&nbsp;&raquo; is available in:',
'mois_non_connu' => 'unknown',

// N
'nouvelles_versions' => 'New versions of SPIP are available',

// O
'onglet_contenu' => 'Contents',
'onglet_declarer_une_autre_base' => 'Declare another database',
'onglet_discuter' => 'Discuss',
'onglet_documents' => 'Documents',
'onglet_interactivite' => 'Interactivity',
'onglet_proprietes' => 'Properties',
'onglet_repartition_actuelle' => 'now',
'onglet_sous_rubriques' => 'Sub-sections',
'ortho_ajouter_ce_mot' => 'Add this word to the dictionary',
'ortho_aucune_suggestion' => 'No suggestion was found for this word.',
'ortho_avis_privacy' => 'Spip contains a spell checker. However, before enabling it, please read the following paragraph carefully:',
'ortho_avis_privacy2' => 'In order to check the spelling of a text, the site will send the list of words to be checked to an external "spelling server", which people of the Spip community have made available. The words are mixed up before being sent in order to maintain some level of confidentiality. If you are concerned about your data, do not activate this option (and withdraw all your information from the web at once).',
'ortho_ce_mot_connu' => 'This word is in the site\'s dictionary.',
'ortho_dico_absent' => 'No dictionary was found for this language',
'ortho_mode_demploi' => 'Urecognised words have been highlighted in red. Click on these words to see suggested corrections.',
'ortho_mots_a_corriger' => 'words to correct',
'ortho_orthographe' => 'Spelling',
'ortho_supprimer_ce_mot' => 'Remove this word from the dictionary',
'ortho_trop_de_fautes' => 'Your text contains too many mistakes! In order to avoid overloading the system, no corrections have been suggested.',
'ortho_verif_impossible' => 'The system cannot check the spelling of this text.',
'ortho_verifier' => 'Spell check',

// P
'page_pas_proxy' => 'This page shouldn\'t go through the proxy',
'pas_de_proxy_pour' => 'If necessary, indicate for which machines or domains this proxy should not apply (for example: @exemple@)',
'plugin_charge_paquet' => 'Loading the archive file @name@',
'plugin_charger' => 'Download',
'plugin_erreur_charger' => 'error: impossible to load @zip@',
'plugin_erreur_droit1' => 'The directory <code>@dest@</code> cannot be written to.',
'plugin_erreur_droit2' => 'Please check the write permissions for this directory (and create the directory if necessary). Alternatively, install the files by FTP.',
'plugin_erreur_zip' => 'pclzip failure: error @status@',
'plugin_etat_developpement' => 'under development',
'plugin_etat_experimental' => 'experimental',
'plugin_etat_stable' => 'stable',
'plugin_etat_test' => 'being tested',
'plugin_impossible_activer' => 'Impossible to activate the plugin  @plugin@',
'plugin_info_automatique1' => 'If you wish to authorise the automatic installation of plugins, please:',
'plugin_info_automatique1_lib' => 'If you wish to authorise the automatic installation of this library, please:',
'plugin_info_automatique2' => 'Create a directory <code>@rep@</code>&nbsp;;',
'plugin_info_automatique3' => 'Check that the server has the permissions to write in this directory.',
'plugin_info_automatique_creer' => 'to create at the root of the website.',
'plugin_info_automatique_exemples' => 'examples:',
'plugin_info_automatique_ftp' => 'You may install plugins by FTP in the  <tt>@rep@</tt> directory',
'plugin_info_automatique_lib' => 'Some plugins require to be able to load files into the <code>lib/</code> directory. This directory should be created, if necessary, at the root of the website.',
'plugin_info_automatique_liste' => 'Your plugins lists:',
'plugin_info_automatique_liste_officielle' => 'official plugins',
'plugin_info_automatique_liste_update' => 'Update the lists',
'plugin_info_automatique_ou' => 'or...',
'plugin_info_automatique_select' => 'Select a plugin below: SPIP will load it and will install it in the <code>@rep@</code> directory. If the plugin already exists, it will be updated.',
'plugin_info_extension_1' => 'The extensions below are loaded and active in the @extensions@ directory.',
'plugin_info_extension_2' => 'They cannot be uninstalled.',
'plugin_info_telecharger' => 'load from @url@ and install to @rep@',
'plugin_librairies_installees' => 'Installed libraries',
'plugin_necessite_lib' => 'This plugin requires the library @lib@',
'plugin_necessite_plugin' => 'Version @version@ or newer of the plugin @plugin@ is required.',
'plugin_necessite_spip' => 'SPIP version @version@ or newer is required.',
'plugin_source' => 'source:&nbsp;',
'plugin_titre_automatique' => 'Automatic installation',
'plugin_titre_automatique_ajouter' => 'Add plugins',
'plugin_titre_installation' => 'Installation of the @plugin@ plugin',
'plugin_zip_active' => 'Continue in order to activate',
'plugin_zip_adresse' => 'Below, give the address of a zip file of a plugin to be loaded, or else the address of a list of plugins.',
'plugin_zip_adresse_champ' => 'Address of the plugin or of the list&nbsp;',
'plugin_zip_content' => 'It contains the following files(@taille@),<br />ready to be installed in the <code>@rep@</code> directory',
'plugin_zip_installe_finie' => 'The file @zip@ has been unpacked and installed.',
'plugin_zip_installe_rep_finie' => 'The file @zip@ has been unpacked and installed in the @rep@ directory',
'plugin_zip_installer' => 'You can install it now.',
'plugin_zip_telecharge' => 'The file @zip@ has been loaded',
'plugins_actif_aucun' => 'No plugin is active.',
'plugins_actif_un' => 'One plugin active',
'plugins_actifs' => '@count@ active plugins.',
'plugins_actifs_liste' => 'Active plugins',
'plugins_compte' => '@count@ plugins',
'plugins_disponible_un' => 'One plugin available',
'plugins_disponibles' => '@count@ available plugins.',
'plugins_erreur' => 'Error in the plugins: @plugins@',
'plugins_liste' => 'Plugin list',
'plugins_liste_extensions' => 'Extensions',
'plugins_recents' => 'Recent plugins',
'plugins_vue_hierarchie' => 'Hierarchy',
'plugins_vue_liste' => 'List',
'protocole_ldap' => 'Protocol version:',

// R
'repertoire_plugins' => 'Directory:',

// S
'sans_heure' => 'time unspecified',
'sauvegarde_fusionner' => 'Merge the current database with the backup',
'sauvegarde_fusionner_depublier' => 'Unpublish the merged objects',
'sauvegarde_url_origine' => 'If necessary, the URL of the source site:',
'statut_admin_restreint' => '(restricted admin)',
'syndic_choix_moderation' => 'What should be done with the next links from this site?',
'syndic_choix_oublier' => 'What should be done with links which are no longer present in the syndication file?',
'syndic_choix_resume' => 'Some sites offer the full text of their articles. When the full text is available, do you wish to syndicate:',
'syndic_lien_obsolete' => 'obsolete link',
'syndic_option_miroir' => 'block them automatically',
'syndic_option_oubli' => 'delete them (after @mois@&nbsp;months)',
'syndic_option_resume_non' => 'the full content of the articles (HTML format)',
'syndic_option_resume_oui' => 'just a summary (text format)',
'syndic_options' => 'Syndication options:',

// T
'taille_cache_image' => 'The images calculated automatically by SPIP (thumbnails, titles transformed into graphics, mathematical formulae in TeX format, etc.) take up a total of @taille@ in the @dir@ directory.',
'taille_cache_infinie' => 'This site does not have any fixed limit for the size of the cache directory.',
'taille_cache_maxi' => 'SPIP is trying to limit the size of the cache directory to approximately <b>@octets@</b> of data.',
'taille_cache_octets' => 'The size of the cache is currently @octets@.',
'taille_cache_vide' => 'The cache is empty.',
'taille_repertoire_cache' => 'Current size of the cache',
'text_article_propose_publication' => 'Article submitted for publication.',
'text_article_propose_publication_forum' => 'You can comment on this article by using the attached forum (at the bottom of the page).',
'texte_acces_ldap_anonyme_1' => 'Some LDAP servers do not allow any anonymous access. In this case you must indicate an initial access identifier to be able to search for information in the directory afterwards. However, in most cases the following fields can be left empty.',
'texte_admin_effacer_01' => 'This command deletes <i>all</i> the content of the database,
including <i>all</i> the access parameters for editors and administrators. After executing it, you should
reinstall SPIP in order to recreate a new database and the first administrator\'s access.',
'texte_admin_effacer_stats' => 'This command deletes all data linked to the statistics of visits to the site, including the relative popularity of articles.',
'texte_admin_tech_01' => 'This option allows you to save the content of the database in a file stored in the directory @dossier@. Also, remember to retrieve the whole @img@, directory, which contains the images and the documents used in the articles and sections.',
'texte_admin_tech_02' => 'Warning: this backup can ONLY be restored by the same version of SPIP that created it. You should not "empty the database" and expect to re-install the backup after the upgrade... For more information refer to <a href="@spipnet@">SPIP documentation</a>.',
'texte_admin_tech_03' => 'You can choose to save the file in a compressed form, to 
	speed up its transfer to your machine or to a backup server and save some disk space.',
'texte_admin_tech_04' => 'In order to merge with another database, you can restrict the backup to one section: ',
'texte_adresse_annuaire_1' => '( If your directory is installed on the same machine as your Web site, it is probably &laquo;localhost&raquo;.)',
'texte_ajout_auteur' => 'The following author was added to the article:',
'texte_annuaire_ldap_1' => 'If you have access to a (LDAP) directory, you can use it to automatically import users under SPIP.',
'texte_article_statut' => 'Article status:',
'texte_article_virtuel' => 'Virtual article',
'texte_article_virtuel_reference' => '<b>Virtual article:</b> referenced article in your SPIP site, but redirected to another URL. To remove redirection, delete the above URL.',
'texte_aucun_resultat_auteur' => 'No results for "@cherche_auteur@".',
'texte_auteur_messagerie' => 'This site can continuously monitor the list of connected editors, which allows you to exchange messages in real time. You can decide not to appear in this list (you are then, "invisible" for the other users).',
'texte_auteur_messagerie_1' => 'This site allows the exchange of messages and the creation of private discussion forums between participants to the site. You can decide not to participate to this exchange.',
'texte_auteurs' => 'THE AUTHORS',
'texte_breves' => 'News are short and simple texts which allow
	the publication online of concise information, the management of
	a press review, a calendar of events...',
'texte_choix_base_1' => 'Select your database:',
'texte_choix_base_2' => 'The SQL server contains several databases.',
'texte_choix_base_3' => '<b>Select</b> below the one that your internet provider has attributed to you:',
'texte_choix_table_prefix' => 'Prefix for tables:',
'texte_commande_vider_tables_indexation' => 'Use this command to empty the indexing tables used
			by the search engine integrated to SPIP. It will allow you
			to save some disk space.',
'texte_comment_lire_tableau' => 'The rank of the article,
		in the popularity classification, is indicated in the
		margin; the article popularity (an estimate of
		the number of daily visits it will have if the actual pace of
		traffic is maintained) and the number of visits recorded
		since the beginning are displayed in the balloon that
		appears as the mouse hovers over the title.',
'texte_compacter_avertissement' => 'Be careful not to activate these options during the development of your site: compressed elements become difficult to read and debug.',
'texte_compacter_script_css' => 'SPIP can compact Javascript files and CSS stylesheets and save them as static files. This accelerates the display of the site.',
'texte_compresse_ou_non' => '(this one could be compressed or not)',
'texte_compresseur_page' => 'SPIP can automatically compress each page that it sends. This option reduces the bandwidth used, making the site faster for lower speed connections), but it does require more resources from the server.',
'texte_compte_element' => '@count@ element',
'texte_compte_elements' => '@count@ elements',
'texte_config_groupe_mots_cles' => 'Do you wish to activate the advanced configuration of keyword groups,
   by specifying, for instance that a unique word
 per group could be selected, that a group is important...?',
'texte_conflit_edition_correction' => 'Please check check below the differences between the two versions. You can thus copy your changes and re-begin.',
'texte_connexion_mysql' => 'Consult the information provided by your service provider. It should contain the connection codes for the SQL server.',
'texte_contenu_article' => '(Content of the article in a few words.)',
'texte_contenu_articles' => 'Based on the layout chosen for your site, you can decide
		that some articles elements are not to be used.
		Use the following list to choose which elements should be available.',
'texte_crash_base' => 'If your database
			crashed, you can try to repair it
			automatically.',
'texte_creer_rubrique' => 'Before being able to write articles,<br /> you must create a section.',
'texte_date_creation_article' => 'DATE OF ARTICLE CREATION:',
'texte_date_publication_anterieure' => 'Date of earlier publishing:',
'texte_date_publication_anterieure_nonaffichee' => 'Hide date of earlier publishing.',
'texte_date_publication_article' => 'DATE OF ONLINE PUBLICATION:',
'texte_descriptif_petition' => 'Petition description',
'texte_descriptif_rapide' => 'Brief description',
'texte_documents_joints' => 'You can allow the addition of documents (office files, images,
 multimedia, etc.) to articles and/or sections. These files
 could then be referenced in
 the article or displayed separately.',
'texte_documents_joints_2' => 'This setting does not stop the insertion of images directly in the articles.',
'texte_effacer_base' => 'Delete the SPIP database',
'texte_effacer_donnees_indexation' => 'Delete indexing data',
'texte_effacer_statistiques' => 'Delete the statistics',
'texte_en_cours_validation' => 'The following articles and news are submitted for publication.',
'texte_en_cours_validation_forum' => 'You can give your comments by using the forums which are attached to them.',
'texte_enrichir_mise_a_jour' => 'You can enrich the layout of your text by using &laquo;typographical shortcuts&raquo;.',
'texte_fichier_authent' => '<b>Should SPIP create the special files <tt>.htpasswd</tt>
  and <tt>.htpasswd-admin</tt> in the directory @dossier@?</b><p>
  These files can be used to restrict access to authors
  and administrators to other parts of your site
  (for instance, external statistical programme).</p><p>
  If you have no need of such files, you can keep this option
  with its default value (no files 
  creation).</p>',
'texte_informations_personnelles_1' => 'The system will provide you now with a custom access to the site.',
'texte_informations_personnelles_2' => '(Note: if it is a reinstallation, and your access is still working, you can',
'texte_introductif_article' => '(Introductory Text to the article.)',
'texte_jeu_caractere' => 'You are advised to use the universal alphabet (<tt>utf-8</tt>) on your site. This will make it possible to display text in any language. No modern browsers have any difficulty with this character set.',
'texte_jeu_caractere_2' => 'N.B. This setting will not convert text which has already been saved in the database.',
'texte_jeu_caractere_3' => 'Your site currently uses this character set:',
'texte_jeu_caractere_4' => 'If that does not correspond to the situation you have with your data (for example, after restoring your database from a backup), or if <em>you are setting up this site</em> and wish to use a different character set, please indicate the character set here:',
'texte_jeu_caractere_conversion' => 'Note: You can decide to convert all the texts (articles, news items, forums, etc.) of your site once and for all to the character set <tt>utf-8</tt>. To do this, go to the <a href="@url@">UTF-8 conversion page</a>.',
'texte_lien_hypertexte' => '(If your message refers to an article published on the Web, or to a page providing more information, please enter here the title of the page and its URL.)',
'texte_liens_sites_syndiques' => 'Links emanating from syndicated sites could
			be blocked beforehand; the following
			setting show the default setting of
			syndicated sites after their creation. It
			is, then, possible anyway to
			block each link individually, or to
			choose, for each site, to block the links coming
			from any particular site.',
'texte_login_ldap_1' => '(Keep empty for anonymous access or enter complete path, for instance &laquo;<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>&raquo;.)',
'texte_login_precaution' => 'Warning! This is the login with which you are connected now.
	Use this form with caution...',
'texte_message_edit' => 'Warning: this message can be modified by all the site administrators, and it appears to all editors. Use the announcements only to stress important events in the site\'s life.',
'texte_messagerie_agenda' => 'A messaging system allows the authors of the site to communicate directly in the editing area of the site. It is linked to a calendar.',
'texte_messages_publics' => 'Public Messages of the article:',
'texte_mise_a_niveau_base_1' => 'You have just updated SPIP files.
	Now you must upgrade the site\'s
	database.',
'texte_modifier_article' => 'Modify the article:',
'texte_moteur_recherche_active' => '<b>The search engine is enabled.</b> use this command
		if you wish to execute a quick re-indexing (after restoring
		a backup for instance). You should note that the documents modified in
		a normal way (from the SPIP interface) are automatically
		indexed again: therefore this command is only useful in exceptional circumstances.',
'texte_moteur_recherche_non_active' => 'The search engine is not enabled.',
'texte_mots_cles' => 'Keywords allow you to create topical links between your articles
  irrespective of their section location. That way you can
  enrich the navigation of your site or even use these properties
  to customise the articles in your templates.',
'texte_mots_cles_dans_forum' => 'Do you wish to allow visitors to select keywords in the public site forums? (Warning: this option is rather intricate to use properly.)',
'texte_multilinguisme' => 'If you wish to manage articles in several languages, with a complicated navigation, you can add a language selection menu to the articles and/or the sections, according to the organisation of your site.',
'texte_multilinguisme_trad' => 'Also, you can enable a link management system amongst the different translations of an article.',
'texte_non_compresse' => '<i>uncompressed</i> (your server does not support this feature)',
'texte_non_fonction_referencement' => 'You can choose not to use this automated feature, and enter the elements concerning that site manually...',
'texte_nouveau_message' => 'New message',
'texte_nouveau_mot' => 'New keyword',
'texte_nouvelle_version_spip_1' => 'You have just installed a new version of SPIP.',
'texte_nouvelle_version_spip_2' => 'This new version requires a more thorough update than usual. If you are the webmaster of this site, please delete the file @connect@ and restart the installation in order to update your database connection parameters. <p>(PS.: if you have forgotten your connection parameters, take a look at the file @connect@ before deleting it!)</p>',
'texte_operation_echec' => 'Go back to the previous page, select another database or create a new one. Verify the information provided by your host.',
'texte_plus_trois_car' => 'more than 3 characters',
'texte_plusieurs_articles' => 'Several authors were found for "@cherche_auteur@":',
'texte_port_annuaire' => '(Default value is generally suitable.)',
'texte_presente_plugin' => 'This page lists the available plugins on the site. Activate the plugins you require by ticking the corresponding box.',
'texte_proposer_publication' => 'When your article is finished,<br /> you can submit it for publication.',
'texte_proxy' => 'In some cases (intranet, protected networks), it is necessary to use an <i>HTTP proxy</i> to reach exterior sites (SPIP documentation, syndicated sites, etc.). If this is the case, enter its address below, in the form @proxy_en_cours@. In most cases you can leave this box empty.',
'texte_publication_articles_post_dates' => 'Which behaviour should SPIP adopt concerning articles which
		publication have been set to
		a future date?',
'texte_rappel_selection_champs' => '[Remember to select this field correctly.]',
'texte_recalcul_page' => 'If you want
to refresh only one page, you would rather do it from the public area and use the button &laquo; refresh &raquo;.',
'texte_recapitiule_liste_documents' => 'This page sums up the list of documents that you have placed in the sections. To modify each document\'s information, follow the link to its section\'s page.',
'texte_recuperer_base' => 'Repair the database',
'texte_reference_mais_redirige' => 'referenced article in your SPIP site, but redirected to another URL.',
'texte_referencement_automatique' => '<b>Automated site referencing</b><br />You can reference a Web site quickly by indicating below the desired URL, or the address of its syndication file. SPIP will automatically retrieve the site\'s information (title, description...).',
'texte_referencement_automatique_verifier' => 'Please, verify the information provided by <tt>@url@</tt> before saving.',
'texte_requetes_echouent' => '<b>When some SQL queries fail
  systematically, without apparent reason, it is possible
  that the database itself
  is the culprit.</b><p>
  The SQL server has a feature for repairing tables
  which have been accidentally
 corrupted. Here, you can attempt to execute this repair; in
  the event of failure, you should keep a copy of the display, which might contain
  clues to where the problem lies.</p><p>
  If the problem persists, contact your 
  service provider.</p>',
'texte_restaurer_base' => 'Restore the content of the database backup',
'texte_restaurer_sauvegarde' => 'This option allows you to restore a previous
backup of the database. To achieve this, the file containing the backup should have been
stored in the directory @dossier@.
Be cautious with this feature: <b>Any potential modifications or losses are
irreversible.</b>',
'texte_sauvegarde' => 'Backup the content of the database',
'texte_sauvegarde_base' => 'Backup the database',
'texte_sauvegarde_compressee' => 'Backup will be stored in the uncompressed file @fichier@.',
'texte_selection_langue_principale' => 'You can select below the "main language" of the site. This does not mean you can only write articles in the selected language, but determines

<ul><li> the default format of the dates on the public site</li>
<li> the nature of the typographical engine which will be used by SPIP for the text rendering;</li>
<li> the language used in the forms of the public site</li>
<li> the default language displayed in the private area.</li></ul>',
'texte_signification' => 'Dark bars represent cumulative entries (total of sub-sections), light bars represent the number of visits for each section.',
'texte_sous_titre' => 'Subtitle',
'texte_statistiques_visites' => '(dark bars:  Sunday / dark curve: average level)',
'texte_statut_attente_validation' => 'pending validation',
'texte_statut_publies' => 'published online',
'texte_statut_refuses' => 'rejected',
'texte_suppression_fichiers' => 'Use this command to delete all the files
in the SPIP cache. This allows you, amongst other things, to force the refreshing of all the pages in case you
entered important modifications on the graphics or the structure of the site.',
'texte_sur_titre' => 'Top title',
'texte_syndication' => 'If a site allows it, it is possible to retrieve automatically
  the list of its latest material. To achieve this, you must activate the syndication. 
  <blockquote><i>Some hosts disable this function; 
  in this case, you cannot use the content syndication
  from your site.</i></blockquote>',
'texte_table_ok' => ': this table is OK.',
'texte_tables_indexation_vides' => 'Indexing tables of the engine are empty.',
'texte_tentative_recuperation' => 'Repairing attempt',
'texte_tenter_reparation' => 'Attempt to repair the database',
'texte_test_proxy' => 'To try this proxy, enter here the address of a Web site
				that you wish to test.',
'texte_titre_02' => 'Subject:',
'texte_titre_obligatoire' => '<b>Title</b> [Required]',
'texte_travail_article' => '@nom_auteur_modif@ has worked on this article @date_diff@ minutes ago',
'texte_travail_collaboratif' => 'If several editors may often   work on the same article, the system can mark the recently &laquo;opened&raquo; articles in order to avoid simultaneous changes being attempted.
  This option is disabled by default to avoid displaying unnecessary warnings.
  messages.',
'texte_trop_resultats_auteurs' => 'Too many results for "@cherche_auteur@"; please refine the search.',
'texte_type_urls' => 'You can choose, below, the calculation mode of the pages URLs.',
'texte_type_urls_attention' => 'Warning, this setting will only work if the file @htaccess@ is correctly installed at the site\'s root.',
'texte_unpack' => 'downloading the latest version',
'texte_utilisation_moteur_syndiques' => 'When you use SPIP\'s integrated search engine, 
you can perform searches on sites and
 articles syndicated in two different ways. <br />- The simplest
 way is to search only in the
 titles and descriptions of the articles. <br />-
 A second, much more powerful, method allows
 SPIP to search also in the text
 of the referenced sites. If you
 reference a site, SPIP will perform
 the search in the site\'s text itself.',
'texte_utilisation_moteur_syndiques_2' => 'This method forces SPIP to visit the referenced sites regularly, which could cause a drop in the performance of your own site.',
'texte_vide' => 'empty',
'texte_vider_cache' => 'Empty the cache',
'titre_admin_effacer' => 'Technical maintenance',
'titre_admin_tech' => 'Technical maintenance',
'titre_admin_vider' => 'Technical maintenance',
'titre_articles_syndiques' => 'Syndicated articles pulled out from this site',
'titre_breves' => 'News',
'titre_cadre_afficher_article' => 'Show the articles:',
'titre_cadre_afficher_traductions' => 'Display the state of translation for the following languages:',
'titre_cadre_ajouter_auteur' => 'ADD AN AUTHOR:',
'titre_cadre_forum_administrateur' => 'Administrators private forum',
'titre_cadre_forum_interne' => 'Internal forum',
'titre_cadre_interieur_rubrique' => 'In section',
'titre_cadre_numero_auteur' => 'AUTHOR NUMBER',
'titre_cadre_signature_obligatoire' => '<b>Signature</b> [Required]<br />',
'titre_compacter_script_css' => 'Compression of scripts and CSS',
'titre_compresser_flux_http' => 'Compression of HTTP data',
'titre_config_contenu_notifications' => 'Notifications',
'titre_config_contenu_prive' => 'In the editing area',
'titre_config_contenu_public' => 'On the public site',
'titre_config_fonctions' => 'Site configuration',
'titre_config_forums_prive' => 'Forums in the editing area',
'titre_config_groupe_mots_cles' => 'Configuration of the keyword groups',
'titre_configuration' => 'Site configuration',
'titre_conflit_edition' => 'Conflict while editing',
'titre_connexion_ldap' => 'Options: <b>Your LDAP connection</b>',
'titre_dernier_article_syndique' => 'Latest syndicated articles',
'titre_documents_joints' => 'Attached documents',
'titre_evolution_visite' => 'Visits level',
'titre_forum_suivi' => 'Forums follow-up',
'titre_gauche_mots_edit' => 'KEYWORD NUMBER:',
'titre_groupe_mots' => 'KEYWORD GROUP:',
'titre_langue_article' => 'ARTICLE LANGUAGE',
'titre_langue_breve' => 'NEWS ITEM LANGUAGE',
'titre_langue_rubrique' => 'SECTION LANGUAGE',
'titre_langue_trad_article' => 'ARTICLE LANGUAGE AND TRANSLATIONS',
'titre_les_articles' => 'ARTICLES',
'titre_messagerie_agenda' => 'Messaging system and calendar',
'titre_mots_cles_dans_forum' => 'Keywords in the public site forums',
'titre_mots_tous' => 'Keywords',
'titre_naviguer_dans_le_site' => 'Browse the site...',
'titre_nouveau_groupe' => 'New group',
'titre_nouvelle_breve' => 'New news item',
'titre_nouvelle_rubrique' => 'New section',
'titre_numero_rubrique' => 'SECTION NUMBER:',
'titre_page_admin_effacer' => 'Technical maintenance: deleting the database',
'titre_page_articles_edit' => 'Modify: @titre@',
'titre_page_articles_page' => 'Articles',
'titre_page_articles_tous' => 'The entire site',
'titre_page_auteurs' => 'Visitors',
'titre_page_breves' => 'News',
'titre_page_breves_edit' => 'Modify the news item: &laquo;@titre@&raquo;',
'titre_page_calendrier' => 'Calendar @nom_mois@ @annee@',
'titre_page_config_contenu' => 'Site configuration',
'titre_page_config_fonctions' => 'Site configuration',
'titre_page_configuration' => 'Site configuration',
'titre_page_controle_petition' => 'Petitions follow-up',
'titre_page_delete_all' => 'total and irreversible deletion',
'titre_page_documents_liste' => 'Attached documents',
'titre_page_forum' => 'Administrators forum',
'titre_page_forum_envoi' => 'Send a message',
'titre_page_forum_suivi' => 'Forums follow-up',
'titre_page_index' => 'Your private area',
'titre_page_message_edit' => 'Write a message',
'titre_page_messagerie' => 'Your messaging',
'titre_page_mots_tous' => 'Keywords',
'titre_page_recherche' => 'Search results @recherche@',
'titre_page_sites_tous' => 'Referenced sites',
'titre_page_statistiques' => 'Statistics by section',
'titre_page_statistiques_messages_forum' => 'Forum messages',
'titre_page_statistiques_referers' => 'Statistics (incoming links)',
'titre_page_statistiques_signatures_jour' => 'Signatures count by day',
'titre_page_statistiques_signatures_mois' => 'Signatures count by month',
'titre_page_statistiques_visites' => 'Visits statistics',
'titre_page_upgrade' => 'SPIP upgrade',
'titre_publication_articles_post_dates' => 'Publication of post dated articles',
'titre_referencement_sites' => 'Sites referencing and syndication',
'titre_referencer_site' => 'Reference the site:',
'titre_rendez_vous' => 'APPOINTMENTS:',
'titre_reparation' => 'Repair',
'titre_site_numero' => 'SITE NUMBER:',
'titre_sites_proposes' => 'Submitted sites',
'titre_sites_references_rubrique' => 'Referenced sites in this section',
'titre_sites_syndiques' => 'Syndicated sites',
'titre_sites_tous' => 'Referenced sites',
'titre_suivi_petition' => 'Petitions follow-up',
'titre_syndication' => 'Sites syndication',
'titre_type_urls' => 'Type of URL addresses',
'tls_ldap' => 'Transport Layer Security :',
'tout_dossier_upload' => 'The whole @upload@ directory',
'trad_article_inexistant' => 'There is no article with this number',
'trad_article_traduction' => 'All the versions of this article:',
'trad_deja_traduit' => 'Error: impossible to link this article to the requested number.',
'trad_delier' => 'Stop linking this article to its translations',
'trad_lier' => 'This article is a translation of article number:',
'trad_new' => 'Write a new translation of this article',

// U
'upload_fichier_zip' => 'ZIP file',
'upload_fichier_zip_texte' => 'The file you are intending to install is a ZIP file.',
'upload_fichier_zip_texte2' => 'This file can be:',
'upload_info_mode_document' => 'Place this image in the portfolio',
'upload_info_mode_image' => 'Remove this image from the portfolio',
'upload_limit' => 'This file is too big for the server; the maximum size allowed for <i>upload</i> is @max@.',
'upload_zip_conserver' => 'Keep the archive file after extracting its contents',
'upload_zip_decompacter' => 'decompressed and each file it contains will be installed on the site. The files which will be installed are:',
'upload_zip_telquel' => 'installed as is, as a ZIP file;',
'upload_zip_titrer' => 'Add titles according to the filenames',
'utf8_convert_attendez' => 'Wait a few seconds and then reload this page.',
'utf8_convert_avertissement' => 'You are about to convert the contents of your database (articles, news items, etc) from the character set <b>@orig@</b> to the character set <b>@charset@</b>.',
'utf8_convert_backup' => 'Don\'t forget to first make a complete backup of your site. You need also to check that your templates and language files are compatible with @charset@.',
'utf8_convert_erreur_deja' => 'Your site is already in @charset@, there is no point in converting.',
'utf8_convert_erreur_orig' => 'Error: the character set @charset@ is not supported.',
'utf8_convert_termine' => 'Finished!',
'utf8_convert_timeout' => '<b>Important:</b> If the server  indicates <i>timeout</i>, please continue to reload the page until you receive the message &laquo;Finished!&raquo;.',
'utf8_convert_verifier' => 'You now need to empty the site cache and then check if all is well on the public pages of the site. If you are stuck with a major problem, a backup of your original data (in SQL format) has been made in the @rep@ directory.',
'utf8_convertir_votre_site' => 'Convert your site to utf-8',

// V
'version' => 'Version:',
'version_deplace_rubrique' => 'Moved from <b>&laquo;&nbsp;@from@&nbsp;&raquo;</b> to <b>&laquo;&nbsp;@to@&nbsp;&raquo;</b>.',
'version_initiale' => 'Initial version'
);

?>
